@@ -15,12 +15,16 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 #{{{sub new
 sub new {
-    my ( $class, @args ) = @_;
-    my $authn = $class->SUPER::new(@args);
+    my ( $class, $nakamura ) = @_;
+    # Set the Referer to /dev/integrationtests in order to be
+    # allowed to post to the Sakai Nakamura instance:
+    ${ $nakamura }->{'Referer'} = '/dev/integrationtests';
+    my $authn = $class->SUPER::new($nakamura);
+    ${$nakamura}->{'Authn'} = \$authn;
     bless $authn, $class;
     return $authn;
 }
@@ -134,6 +138,7 @@ sub switch_user {
 sub login_user {
     my ($authn) = @_;
     my $success = 1;
+    $authn->{'Type'} = ( defined $authn->{'Type'} ? $authn->{'Type'} : 'form' );
 
     # Apply basic authentication to the user agent if url, username and
     # password are supplied:
